@@ -1,14 +1,14 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import List, TypeVar, Tuple, Generic
 
 from pydantic import BaseModel as PdModel
 from tortoise.exceptions import IntegrityError, FieldError
 from tortoise.queryset import QuerySet, MODEL
 
+from web_foundation.app.errors.application.application import InconsistencyError
 from web_foundation.app.infrastructure.database.models import GenericDbType
 from web_foundation.app.infrastructure.database.utils import integrity_error_format
-from web_foundation.workers.web.erorrs.application import InconsistencyError
-from web_foundation.workers.web.sanic_ext.structs import ProtectIdentity
+from web_foundation.workers.io.http.chaining import ProtectIdentity
 
 EntityId = TypeVar("EntityId", bound=int)
 
